extract

Function extract 

pub fn extract(raw: &str, decimals: usize) -> Result<Decimal, OverpunchError>
Returns a Decimal parsed from an appropriate signed overpunch respresentation.

Arguments

  • value - The signed overpunch representation.
  • decimals - The number of digits following the decimal point that this value has.

Example


let number = extract("2258{", 2).unwrap();
assert_eq!(number, Decimal::from_str_exact("225.8").unwrap());